@@ -65,7 +65,7 @@ class InboxPermissions(WACPermissions):
     """
     anonymous_perms = ['create']
     authenticated_perms = ['create']
-    author_perms = ['view', 'update']
+    author_perms = ['view', 'update', 'partial_update']
 
     def has_permission(self, request, view):
         if view.action in ['create']:
@@ -80,10 +80,10 @@ class InboxPermissions(WACPermissions):
             return super().has_object_permission(request, view, obj)
 
     def user_permissions(self, user, obj):
-        if user.is_anonymous:
+        if user.is_anonymous():
             return self.anonymous_perms
         else:
-            if Model.get_meta(obj, 'auto_author') == user:
+            if hasattr(obj._meta, 'auto_author') and getattr(obj, Model.get_meta(obj, 'auto_author')) == user:
                 return self.author_perms
             else:
                 return self.authenticated_perms
@@ -103,7 +103,7 @@ class AnonymousReadOnly(WACPermissions):
     def has_permission(self, request, view):
         if view.action in ['list', 'retrieve']:
             return True
-        elif view.action == 'create' and request.user.is_authenticated():
+        elif view.action in ['create', 'update', 'partial_update'] and request.user.is_authenticated():
             return True
         else:
             return super().has_permission(request, view)
@@ -114,18 +114,15 @@ class AnonymousReadOnly(WACPermissions):
         elif view.action in ["list", "retrieve"]:
             return True
         elif view.action in ['update', 'partial_update', 'destroy']:
-            if hasattr(obj._meta, 'auto_author'):
-                author = getattr(obj, obj._meta.auto_author)
-                if author == request.user:
-                    return True
-        else:
-            return super().has_object_permission(request, view, obj)
+            if hasattr(obj._meta, 'auto_author') and getattr(obj, Model.get_meta(obj, 'auto_author')) == request.user:
+                return True
+        return super().has_object_permission(request, view, obj)
 
     def user_permissions(self, user, obj):
-        if user.is_anonymous:
+        if user.is_anonymous():
             return self.anonymous_perms
         else:
-            if Model.get_meta(obj, 'auto_author') == user:
+            if hasattr(obj._meta, 'auto_author') and getattr(obj, Model.get_meta(obj, 'auto_author')) == user:
                 return self.author_perms
             else:
                 return self.authenticated_perms
@@ -153,7 +150,7 @@ class LoggedReadOnly(WACPermissions):
             return super().has_object_permission(request, view, obj)
 
     def user_permissions(self, user, obj):
-        if user.is_anonymous:
+        if user.is_anonymous():
             return self.anonymous_perms
         else:
             return self.authenticated_perms
