@@ -127,7 +127,6 @@ class ManyJsonLdRelatedField(LDListMixin, ManyRelatedField):
     url_field_name = "@id"
 
 
-
 class JsonLdField(HyperlinkedRelatedField):
     def __init__(self, view_name=None, **kwargs):
         super().__init__(view_name, **kwargs)
@@ -253,13 +252,27 @@ class LDPSerializer(HyperlinkedModelSerializer):
                         obj = next(filter(
                             lambda o: not hasattr(o, self.parent.url_field_name) or "./" in o[self.url_field_name],
                             object_list))
-                        return super().get_value(obj)
+                        value = super().get_value(obj)
                     else:
                         resource_id = Model.resource_id(self.parent.instance)
-                        obj = next(filter(lambda o: resource_id.lstrip('/') in o[self.parent.url_field_name], object_list))
-                        return super().get_value(obj)
+                        obj = next(
+                            filter(lambda o: resource_id.lstrip('/') in o[self.parent.url_field_name], object_list))
+                        value = super().get_value(obj)
                 except KeyError:
-                    return super().get_value(dictionary)
+                    value = super().get_value(dictionary)
+
+                return self.manage_empty(value)
+
+            def manage_empty(self, value):
+                if value == '' and self.allow_null:
+                    # If the field is blank, and null is a valid value then
+                    # determine if we should use null instead.
+                    return '' if getattr(self, 'allow_blank', False) else None
+                elif value == '' and not self.required:
+                    # If the field is blank, and emptiness is valid then
+                    # determine if we should use emptiness instead.
+                    return '' if getattr(self, 'allow_blank', False) else empty
+                return value
 
         field_class, field_kwargs = super().build_standard_field(field_name, model_field)
         field_kwargs['parent_view_name'] = '{}-list'.format(model_field.model._meta.object_name.lower())
@@ -279,6 +292,8 @@ class LDPSerializer(HyperlinkedModelSerializer):
                     fields = '__all__'
 
             def to_internal_value(self, data):
+                if data is '':
+                    return ''
                 if self.url_field_name in data:
                     if not isinstance(data, Mapping):
                         message = self.error_messages['invalid'].format(
@@ -364,13 +379,15 @@ class LDPSerializer(HyperlinkedModelSerializer):
                     object_list))
             else:
                 container_id = Model.container_id(self.parent.instance)
-                obj = next(filter(lambda o: container_id in o[self.url_field_name], object_list))
+                obj = next(filter(lambda o: container_id.lstrip('/') in o[self.url_field_name], object_list))
             item = super().get_value(obj)
             full_item = None
             if item is empty:
                 return empty
             try:
-                full_item = next(filter(lambda o: self.url_field_name in o and (item[self.url_field_name] == o[self.url_field_name]), object_list))
+                full_item = next(
+                    filter(lambda o: self.url_field_name in o and (item[self.url_field_name] == o[self.url_field_name]),
+                           object_list))
             except StopIteration:
                 pass
             if full_item is None:
@@ -412,7 +429,7 @@ class LDPSerializer(HyperlinkedModelSerializer):
                 kwargs = {slug_field: field_dict[slug_field]}
                 sub_inst = field_model.objects.get(**kwargs)
             else:
-                sub_inst = self.internal_create(field_dict, field_model )
+                sub_inst = self.internal_create(field_dict, field_model)
             validated_data[field_name] = sub_inst
 
         nested_fields = []
@@ -434,15 +451,11 @@ class LDPSerializer(HyperlinkedModelSerializer):
 
         for attr, value in validated_data.items():
             if isinstance(value, dict):
-                slug_field = Model.slug_field(instance)
-                manager = getattr(instance, attr)
-                if slug_field in value:
-                    kwargs = {slug_field: value[slug_field]}
-                    oldObj = manager._meta.model.objects.get(**kwargs)
-                    value = self.update(instance=oldObj, validated_data=value)
-                else:
-                    value = self.internal_create(validated_data=value, model=manager._meta.model)
-            setattr(instance, attr, value)
+                value = self.update_dict_value(attr, instance, value)
+            if value is '' and not isinstance(getattr(instance, attr), str):
+                setattr(instance, attr, None)
+            else:
+                setattr(instance, attr, value)
 
         instance.save()
 
@@ -450,6 +463,39 @@ class LDPSerializer(HyperlinkedModelSerializer):
 
         return instance
 
+    def update_dict_value(self, attr, instance, value):
+        info = model_meta.get_field_info(instance)
+        slug_field = Model.slug_field(instance)
+        relation_info = info.relations.get(attr)
+        if slug_field in value:
+            value = self.update_dict_value_when_id_is_provided(attr, instance, relation_info, slug_field, value)
+        else:
+            value = self.update_dict_value_without_slug_field(attr, instance, relation_info, value)
+        return value
+
+    def update_dict_value_without_slug_field(self, attr, instance, relation_info, value):
+        if relation_info.to_many:
+            value = self.internal_create(validated_data=value, model=relation_info.related_model)
+        else:
+            value[instance._meta.fields_map[attr].remote_field.name] = instance
+            oldObj = getattr(instance, attr, None)
+            if oldObj is None:
+                value = self.internal_create(validated_data=value, model=relation_info.related_model)
+            else:
+                value = self.update(instance=oldObj, validated_data=value)
+        return value
+
+    def update_dict_value_when_id_is_provided(self, attr, instance, relation_info, slug_field, value):
+        kwargs = {slug_field: value[slug_field]}
+        if relation_info.to_many:
+            manager = getattr(instance, attr)
+            oldObj = manager._meta.model.objects.get(**kwargs)
+        else:
+            oldObj = getattr(instance, attr)
+
+        value = self.update(instance=oldObj, validated_data=value)
+        return value
+
     def save_or_update_nested_list(self, instance, nested_fields):
         for (field_name, data) in nested_fields:
             manager = getattr(instance, field_name)
@@ -457,7 +503,8 @@ class LDPSerializer(HyperlinkedModelSerializer):
             try:
                 item_pk_to_keep = list(map(lambda e: e[slug_field], filter(lambda x: slug_field in x, data)))
             except TypeError:
-                item_pk_to_keep = list(map(lambda e: getattr(e, slug_field), filter(lambda x: hasattr(x, slug_field), data)))
+                item_pk_to_keep = list(
+                    map(lambda e: getattr(e, slug_field), filter(lambda x: hasattr(x, slug_field), data)))
 
             for item in list(manager.all()):
                 if not str(getattr(item, slug_field)) in item_pk_to_keep:
