@@ -20,7 +20,10 @@ urlpatterns = [
 ]
 
 for package in settings.DJANGOLDP_PACKAGES:
-    import_module('{}.models'.format(package))
+    try:
+        import_module('{}.models'.format(package))
+    except ModuleNotFoundError:
+        pass
 
 model_classes = {cls.__name__: cls for cls in Model.__subclasses__()}
 
@@ -34,3 +37,9 @@ for class_name in model_classes:
                  permission_classes=Model.get_meta(model_class, 'permission_classes', []),
                  fields=Model.get_meta(model_class, 'serializer_fields', []),
                  nested_fields=Model.get_meta(model_class, 'nested_fields', [])))))
+
+for package in settings.DJANGOLDP_PACKAGES:
+    try:
+        urlpatterns.append(url(r'^', include('{}.djangoldp_urls'.format(package))))
+    except ModuleNotFoundError:
+        pass
